pub enum UmamiError {
RequestFailed(Error),
JsonParseError(Error),
}Expand description
When something goes wrong, an UmamiError is used to describe what happened.
Variants
RequestFailed(Error)
A generic error used when none of the other possible errors are fitting.
JsonParseError(Error)
Happens if the API gives us an unexpected object, likely means there’s a mistake with this crate (or a bad struct given to request()).