Umami

Struct Umami 

pub struct Umami {
    pub client: Client,
    pub token: Token,
    pub instance: String,
}

Fields

client: Clienttoken: Tokeninstance: String

Implementations

Source

impl Umami

Source

impl Umami

pub fn get_stats( &self, website_id: impl Into<String>, timestamps: Timestamps, ) -> GetStatsRequestBuilder<'_>

Source

impl Umami

pub async fn new( instance: String, username: String, password: String, ) -> Result<Self, UmamiError>

Create a new Umami client, which you’ll use to make your requests!

  • instance - The URL of the instance’s API route, for example https://your-umami-instance.com/api.
  • username - The username of the user you want to authenticate as.
  • password - The password of the user you want to authenticate as.
pub async fn request<T: DeserializeOwned, P: Serialize + Sized>( &self, method: &str, endpoint: &str, params: P, ) -> Result<T, UmamiError>