pub struct StatsWithComparison {
pub base: Stats,
pub comparison: Stats,
}Fields
base: StatsThe Stats for a given time period
comparison: StatsThe Stats for a time period which is of the same length as a given time period, and ends when that given time period begins